pub enum EventKind {
LlmCall,
ToolCall,
ReplExec,
Rpc,
Budget,
Guardrail,
Retry,
Termination,
Log,
Custom,
}Expand description
Kind of an intra-span event — a point-in-time occurrence within a span’s lifetime (a retry, a budget check, a guardrail trip, an REPL step), as opposed to a span, which has a duration.
Variants